import request from '@/utils/request'

// 角色管理列表
export function getRoleList(data: any) {
  return request.post('/sys/role/data', data)
}
// 新增角色
export function createRole(data: any) {
  return request.post('/sys/role/save', data)
}
//删除角色
export function delRole(data: any) {
  return request.get('/sys/role/delete', {
    params: data
  })
}

// 分配用户列表
export function getRoleUserList(data: any) {
  return request.post('/sys/role/assign', data)
}
// 新增分配用户
export function createRoleUser(data: any) {
  return request.post('/sys/role/assignrole', data)
}
// 移除用户
export function delRoleUser(data: any) {
  return request.post('/sys/role/outrole', data)
}
